<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Misc</name>
    <message>
        <location filename="../Misc.js" line="+60"/>
        <source>Misc Tools</source>
        <translation>その他ツール</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show misc tools</source>
        <translation>表示その他ツール</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Misc</source>
        <translation>その他</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Misc</source>
        <translation>&amp;M 雑多</translation>
    </message>
</context>
</TS>
